
Tailbone
========

Tailbone is an extensible web application based on Rattail.  It provides a
"back-office network environment" (BONE) for use in managing retail data.

Please see Rattail's `home page`_ for more information.

.. _home page: http://rattailproject.org/
